simple_app_state library

Classes

AppStateGroup
(en) A class that groups multiple SimpleAppState and RefAppState instances for coordinated batch processing.
RefAppState
RefSlot<T>
SimpleAppState
SlotState<T extends SlotStatefulWidget>
SlotStatefulWidget
(en) A stateful widget that is tied to state management and automatically updates the screen. Users can extend this class or use the builder.
StateSlot<T>
StateSlotBuilder
(en) A builder that can be used when you want to update a widget depending on the value of a slot.

Typedefs

DebugListener = void Function(StateSlot key, dynamic oldValue, dynamic newValue)
A listener that returns the old and new values for a key for debugging purposes.
RefDebugListener = void Function(RefSlot key, dynamic ref)
A listener that returns a reference value for a key for debugging purposes.
StateListener = void Function(SimpleAppState nowState)
A listener that is notified when a logical state change is committed. In batch processing, it returns only once at the end of the processing.