simple_app_state
library
Typedefs
-
DebugListener
= void Function(StateSlot key, dynamic oldValue, dynamic newValue)
-
A listener that returns the old and new values for a key for
debugging purposes.
-
RefDebugListener
= void Function(RefSlot key, dynamic ref)
-
A listener that returns a reference value for a key for debugging purposes.
-
StateListener
= void Function(SimpleAppState nowState)
-
A listener that is notified when a logical state change is committed.
In batch processing, it returns only once at the end of the processing.